@@ -64,6 +64,7 @@ use pEFL::Elm::Separator;
 use pEFL::Elm::Slider;
 use pEFL::Elm::Spinner;
 use pEFL::Elm::Table;
+use pEFL::Elm::Theme;
 use pEFL::Elm::Toolbar;
 use pEFL::Elm::ToolbarItem;
 use pEFL::Elm::Tooltip;
@@ -212,6 +213,9 @@ ELM_FLIP_DIRECTION_UP
 ELM_FLIP_DIRECTION_DOWN
 ELM_FLIP_DIRECTION_LEFT
 ELM_FLIP_DIRECTION_RIGHT
+ELM_FOCUS_MOVE_POLICY_CLICK
+ELM_FOCUS_MOVE_POLICY_IN
+ELM_FOCUS_MOVE_POLICY_KEY_ONLY
 ELM_GLVIEW_NONE
 ELM_GLVIEW_ALPHA
 ELM_GLVIEW_DEPTH
